#!/bin/bash

# Title         : 3G/uploader.sh
# Description   : Background process to upload xgoldscanner log files to GSMmap
# Author        : Tim Hummel, The SRLabs Team
# Usage         : 3G/uploader.sh
# Notes         : This script is part of the standalone version of xgoldscanner

scriptDirectory="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
source $scriptDirectory/colors

logfolder_tmp=$1 #First argument is the logfolder_tmp
offline=$2 #Second argument is if we are in offline mode
curl=$3 #Second argument is the $curl used
Keep_Unencrypted=$4 #Second argument is if we keep the logfiles instead of deleting them
BINARYENCRYPT="openssl smime -encrypt -binary -aes256 -outform DER " #required parameters: -out output smime.crt (and input)
Certbundle=$scriptDirectory/ca.pem

function EncryptingLog(){
	echo -n -e "Encrypting log... "
		$BINARYENCRYPT -in $filename -out $filename.smime ${scriptDirectory}/smime.crt
		if [[ $? -ne 0 ]]; then
			red "Encryption failed. Keeping file in temporary storage: $filename"
		fi
		if [[ $Keep_Unencrypted == "yes" ]]; then
			mkdir -p ~/3G_Measurement_Logfiles/ 2>/dev/null
			base=`basename ${filename}`
			cp $filename ~/3G_Measurement_Logfiles/${base}
			red "Keeping unencrypted file: ~/3G_Measurement_Logfiles/${base}"
		fi
		shred -fu $filename
	green "DONE."
}

function UploadLog(){
	$curl -s --cacert $Certbundle --capath /dev/null -H Expect: -F "bursts=@-;filename=${filename}" -F submit=batch -F opaque=1 https://gsmmap.srlabs.de:4433/cgi-bin/dat_upload.cgi < ${filename} > /dev/null
	if [ $? -eq 0 ] ; then
		echo -n -e "Uploading last log... " 
		green "DONE."
		shred -fu $filename
		if [ $? -eq 0 ] ; then
			echo -n -e "Deleting local copy of last log... "
			green "DONE.\n"
		else
			echo -n -e "Deleting local copy of last log... " 
			red "FAILED. Please delete $filename manually\n"
		fi
	else
		#we are offline
		echo "stopped" > ${scriptDirectory}/.stopped #shows that the uploader script stopped
	fi
}

if [[ $offline == "offline" ]]; then
	red "WARNING: Skipping upload. Please upload logfiles manually."
fi
if [[ $Keep_Unencrypted == "yes" ]]; then
	red "WARNING: Logfile copy will remain in: ~/3G_Measurement_Logfiles/"
fi

stop=false
while [ $stop == false ]; do
	if [[ -e ${scriptDirectory}/.stopped ]] ; then 
		shred -fu ${scriptDirectory}/.stopped #deletes upload script stop indicator
	fi
	if [ "$(ls -A $logfolder_tmp/xgs.*.gz 2> /dev/null)" ]; then #logfolder contains files
		for filename in $logfolder_tmp/*.gz
		do
			EncryptingLog
		done
	elif [ "$(ls -A $logfolder_tmp/xgs.*.smime 2> /dev/null)" ]; then
		for filename in $logfolder_tmp/*.smime
		do
			if [ $offline == "online" ]; then
				UploadLog
			else #logfolder_tmp is empty
				if [[ -e ${scriptDirectory}/.stop ]] ; then
					stop=true
				fi
			fi
		done
	else #logfolder_tmp is empty
		if [[ -e ${scriptDirectory}/.stop ]] ; then
			stop=true
		fi
	fi
	sleep 5;
done
echo "Upload finished."
rm ${scriptDirectory}/.stop
echo "stopped" > ${scriptDirectory}/.stopped #shows that the uploader script stopped
exit 0
