#!/bin/bash

# Title         : 3G/xgoldscanner.sh
# Description   : Collects RIL-log data for GSMmap
# Author        : Tim Hummel, Linus Neumann, The SRLabs Team
# Usage         : 3G/xgoldscanner.sh
# Notes         : This script is part of the standalone version of xgoldscanner

# Import functions
scriptDirectory="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
source $scriptDirectory/colors
source $scriptDirectory/ramdisk
source $scriptDirectory/xgoldscanner_functions

# Error handling
trap trapHandler EXIT SIGINT
exec 5<> /dev/null

# Initialize
DisplayLogo
Cleanup
if [[ -e ${scriptDirectory}/stop ]] ; then
	shred -fu ${scriptDirectory}/stop
fi
ParseArguments "$@" 3<&0
CheckRequirements
PrepareLog
CheckInternetConnection 3<&0
ConnectModem 3<&0
CheckRamdumpMode 3<&0
DetectPhoneModel 3<&0

# WCDMA tests
networkMode=2 #WCDMA
networkModeName="WCDMA"
CheckNetworkMode 3<&0
NetworkDetection 3<&0
white "\nNetwork mode: $networkModeName"
while read network; do
	white "Testing network $network in 3G mode"
	ToggleModes
	ExecuteTest
done 3<&0 <$Available_3G_Networks

if [[ $threeGonly ]]
then
	yellow "2G measurement skipped."
else
	# Switch to GSM
	yellow "Please activate GSM-only mode on your phone."
	yellow "(Applications -> Settings -> More -> Mobile Networks -> Network Mode)"
	yellow "Press <ENTER> to continue."
	$READUSERINPUT pause
	echo "$pause" >&5
	sleep 5;

	#GSM tests
	networkMode=0 #GSM
	networkModeName="GSM"
	CheckNetworkMode 3<&0
	while read network; do
		white "\nTesting network $network in 2G mode"
		ExecuteTest
	done 3<&0 <$Available_2G_Networks
fi

#Terminate
end=1
Cleanup
green "All tests completed."
white "Thank you very much for your contribution to GSMmap.org!"

trap - EXIT SIGINT

if [[ -z $threeGonly ]]
then
	#Promt user to switch to GSM
	red "Please switch our your phone back to GSM/WCDMA (Auto mode)."
	red "(Applications -> Settings -> More -> Mobile Networks -> Network Mode)"
	yellow "Press <ENTER> to confirm."
	$READUSERINPUT pause
	echo "$pause" >&5
fi
exit 0
